@@ -26,7 +26,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <gnome.h>
+#include <libgnome/gnome-help.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include "actions.h"
 #include "dlg-add-files.h"
@@ -300,7 +300,7 @@ get_supported_archive_types (void)
 
 	if (is_program_in_path ("zoo")) {
                 write_type_desc[wi].name = g_strdup(N_("Zoo (.zoo)"));
-		write_type_desc[wi].ext = g_strdup(".7z");
+		write_type_desc[wi].ext = g_strdup(".zoo");
                 wi++;
 		save_mime_type[si] = g_strdup("application/x-zoo");
 		si++;
@@ -308,24 +308,16 @@ get_supported_archive_types (void)
 		oi++;
         }
 
-	if (is_program_in_path ("7za")) {
+	if (is_program_in_path ("7za") || is_program_in_path ("7z")) {
                 write_type_desc[wi].name = g_strdup(N_("7-Zip (.7z)"));
-		write_type_desc[wi].ext = g_strdup(".zoo");
+		write_type_desc[wi].ext = g_strdup(".7z");
                 wi++;
 		save_mime_type[si] = g_strdup("application/x-7zip");
 		si++;
 		open_mime_type[oi] = g_strdup("application/x-7zip");
 		oi++;	
 
-        } else if (is_program_in_path ("7z")) {
-		write_type_desc[wi].name = g_strdup(N_("7-Zip (.7z)"));
-		write_type_desc[wi].ext = g_strdup(".7z");
-		wi++;
-		save_mime_type[si] = g_strdup("application/x-7zip");
-		si++;
-		open_mime_type[oi] = g_strdup("application/x-7zip");
-		oi++;
-	}
+        } 
 
 	write_type_desc[wi].name = NULL;
 	write_type_desc[wi].ext = NULL;
@@ -911,356 +903,6 @@ activate_action_save_as (GtkAction *action,
 }
 
 
-/* -- copy and move archive implementation -- */
-
-
-typedef struct {
-	FRWindow  *window;
-	gboolean   copy;
-	gboolean   overwrite;
-	GtkWidget *file_sel;
-} CopyMoveData;
-
-
-static void
-file_sel_destroy_cb (GtkWidget    *w,
-		     CopyMoveData *data)
-{
-	g_free (data);
-}
-
-
-static void 
-copy_or_move_archive_response_cb (GtkWidget    *w,
-				  int           response,
-				  CopyMoveData *data)
-{
-	FRWindow    *window = data->window;
-	char        *folder;
-	char        *new_path;
-
-	if ((response == GTK_RESPONSE_CANCEL) || (response == GTK_RESPONSE_DELETE_EVENT)) {
-		gtk_widget_destroy (w);
-		return;
-	}
-
-	gtk_widget_hide (data->file_sel);
-
-	folder = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (data->file_sel));
-
-	if ((folder == NULL) || (*folder == 0)) {
-		g_free (folder);
-		gtk_widget_show (data->file_sel);
-		return;
-	}
-
-	new_path = g_build_filename (folder, file_name_from_path (window->archive_filename), NULL);
-	g_free (folder);
-
-	if (strcmp (new_path, window->archive_filename) == 0) {
-		gtk_widget_show (data->file_sel);
-		return;
-	}
-
-	if (path_is_file (new_path)) {
-		GtkWidget *d;
-		int        r;
-
-		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
-					     GTK_DIALOG_MODAL,
-					     GTK_STOCK_DIALOG_QUESTION,
-					     _("The archive already exists.  Do you want to overwrite it?"),
-					     NULL,
-					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					     _("Overwrite"), GTK_RESPONSE_YES,
-					     NULL);
-	
-		gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
-		r = gtk_dialog_run (GTK_DIALOG (d));
-		gtk_widget_destroy (GTK_WIDGET (d));
-		
-		if (r != GTK_RESPONSE_YES) {
-			g_free (new_path);
-			gtk_widget_destroy (data->file_sel);
-			return;
-		}
-	}
-	
-	if (data->copy) {
-#ifdef DEBUG
-		g_print ("cp %s %s\n", window->archive_filename, new_path);
-#endif
-		if (! file_copy (window->archive_filename, new_path)) {
-			GtkWidget *dialog;
-			dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
-							  GTK_DIALOG_DESTROY_WITH_PARENT,
-							  GTK_STOCK_DIALOG_ERROR,
-							  _("Could not copy the archive"),
-							  NULL,
-							  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
-							  NULL);
-			gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);
-		}
-	} else {
-#ifdef DEBUG
-		g_print ("mv %s %s\n", window->archive_filename, new_path);
-#endif
-		if (file_move (window->archive_filename, new_path)) 
-			window_archive_rename (window, new_path);
-
-		else {
-			GtkWidget *dialog;
-			dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
-							  GTK_DIALOG_DESTROY_WITH_PARENT,
-							  GTK_STOCK_DIALOG_ERROR,
-							  _("Could not move the archive"),
-							  NULL,
-							  GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
-							  NULL);
-			gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-			gtk_dialog_run (GTK_DIALOG (dialog));
-			gtk_widget_destroy (dialog);
-		}
-	}
-
-	g_free (new_path);
-	gtk_widget_destroy (data->file_sel);
-}
-
-
-static void
-copy_or_move_archive (FRWindow *window, 
-		      gboolean  copy,
-		      gboolean  overwrite)
-{
-	GtkWidget    *file_sel;
-	CopyMoveData *data;
-
-	data = g_new (CopyMoveData, 1);
-	data->window = window;
-	data->copy = copy;
-	data->overwrite = overwrite;
-	data->file_sel = file_sel = 
-		gtk_file_chooser_dialog_new (
-		     copy ? _("Copy") : _("Move"),
-		     GTK_WINDOW (window->app),
-		     GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-		     GTK_STOCK_CANCEL,
-		     GTK_RESPONSE_CANCEL,
-		     copy ? _("_Copy"): _("_Move"),
-		     GTK_RESPONSE_OK,
-		     NULL);
-	gtk_dialog_set_default_response (GTK_DIALOG (file_sel), GTK_RESPONSE_OK);
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel),
-					     window->open_default_dir);
- 
-	g_signal_connect (G_OBJECT (file_sel),
-			  "response", 
-			  G_CALLBACK (copy_or_move_archive_response_cb), 
-			  data);
-
-	g_signal_connect (G_OBJECT (file_sel),
-			  "destroy", 
-			  G_CALLBACK (file_sel_destroy_cb),
-			  data);
-
-	gtk_window_set_modal (GTK_WINDOW (file_sel), TRUE);
-	gtk_widget_show (file_sel);
-}
-
-
-void
-activate_action_copy_archive (GtkAction *action,
-			      gpointer   data)
-{
-	copy_or_move_archive ((FRWindow *) data, TRUE, FALSE);
-}
-
-
-void
-activate_action_move_archive (GtkAction *action,
-			      gpointer   data)
-{
-	copy_or_move_archive ((FRWindow *) data, FALSE, FALSE);
-}
-
-
-/* -- rename archive -- */
-
-
-static char*
-remove_extension (const char *filename)
-{
-	const char *ext;
-
-	ext = fr_archive_utils__get_file_name_ext (filename);
-	if (ext == NULL)
-		return g_strdup (filename);
-	else
-		return g_strndup (filename, strlen (filename) - strlen (ext));
-}
-
-
-void
-activate_action_rename_archive (GtkAction *action,
-				gpointer   data)
-{
-	FRWindow   *window = data;
-	char       *name;
-	char       *utf8_old_string;
-	char       *utf8_string;
-	char       *string;
-	char       *dir, *filename, *new_filename;
-
-	name = remove_extension (file_name_from_path (window->archive_filename));
-	utf8_old_string = g_filename_to_utf8 (name, -1, NULL, NULL, NULL);
-	g_free (name);
-	utf8_string = _gtk_request_dialog_run (GTK_WINDOW (window->app),
-					       (GTK_DIALOG_DESTROY_WITH_PARENT 
-						| GTK_DIALOG_MODAL),
-					       _("Rename"),
-					       _("New archive name (without extension)"),
-					       utf8_old_string,
-					       1024,
-					       GTK_STOCK_CANCEL,
-					       _("_Rename"));
-	g_free (utf8_old_string);
-	if (utf8_string == NULL)
-		return;
-
-	string = g_filename_from_utf8 (utf8_string, -1, NULL, NULL, NULL);
-	g_free (utf8_string);
-
-	filename = window->archive->filename;
-	dir = remove_level_from_path (filename);
-	new_filename = g_strconcat (dir, 
-				    "/", 
-				    file_name_from_path (string),
-				    fr_archive_utils__get_file_name_ext (window->archive->filename),
-				    NULL);
-	g_free (dir);
-	g_free (string);
-
-	if (path_is_file (new_filename)) {
-		GtkWidget *d;
-		int        r;
-
-		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
-					     GTK_DIALOG_MODAL,
-					     GTK_STOCK_DIALOG_QUESTION,
-					     _("The archive already exists.  Do you want to overwrite it?"),
-					     NULL,
-					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					     _("Overwrite"), GTK_RESPONSE_YES,
-					     NULL);
-		gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
-		r = gtk_dialog_run (GTK_DIALOG (d));
-		gtk_widget_destroy (GTK_WIDGET (d));
-		
-		if (r != GTK_RESPONSE_YES) {
-			g_free (new_filename);
-			return;
-		}
-	}
-
-#ifdef DEBUG
-	g_print ("rename %s --> %s\n", filename, new_filename);
-#endif
-
-	if (rename (filename, new_filename) == 0) 
-		window_archive_rename (window, new_filename);
-
-	g_free (new_filename);
-}
-
-
-/* -- delete archive -- */
-
-
-static char *
-get_trash_path (const char *filename)
-{
-	char        *e_filename;
-	GnomeVFSURI *uri, *trash_uri;
-
-	e_filename = gnome_vfs_escape_path_string (filename);
-	uri = gnome_vfs_uri_new (e_filename);
-	g_free (e_filename);
-
-	gnome_vfs_find_directory (uri, 
-				  GNOME_VFS_DIRECTORY_KIND_TRASH,
-				  &trash_uri, 
-				  TRUE,
-				  TRUE,
-				  0777);
-	gnome_vfs_uri_unref (uri);
-
-	if (trash_uri == NULL)
-		return NULL;
-	else {
-		char *trash_path;
-		trash_path = gnome_vfs_uri_to_string (trash_uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);
-		gnome_vfs_uri_unref (trash_uri);
-		return trash_path;
-	}
-}
-
-
-void
-activate_action_delete_archive (GtkAction *action,
-				gpointer   data)
-{
-	FRWindow *window = data;
-	char     *trash_path;
-
-#ifdef DEBUG
-	g_print ("rm %s\n", window->archive->filename);
-#endif
-
-	trash_path = get_trash_path (window->archive->filename);
-
-	if (trash_path == NULL) {
-		GtkWidget *d;
-		int        r;
-		d = _gtk_yesno_dialog_new (GTK_WINDOW (window->app),
-					   GTK_DIALOG_MODAL,
-					   _("The archive cannot be moved to the Trash. Do you want to delete it permanently?"),
-					   GTK_STOCK_NO,
-					   GTK_STOCK_DELETE);
-		
-		gtk_dialog_set_default_response (GTK_DIALOG (d), GTK_RESPONSE_YES);
-		r = gtk_dialog_run (GTK_DIALOG (d));
-		gtk_widget_destroy (GTK_WIDGET (d));
-		
-		if (r == GTK_RESPONSE_YES) {
-			if (unlink (window->archive->filename) == 0)
-				window_archive_close (window);
-		}
-		
-	} else {
-		const char *filename;
-		char       *dest_filename;
-		
-		filename = file_name_from_path (window->archive->filename);
-		if (trash_path[strlen (trash_path) - 1] == '/')
-			dest_filename = g_strconcat (trash_path, 
-						     filename,
-						     NULL);
-		else
-			dest_filename = g_strconcat (trash_path, 
-						     "/", 
-						     filename,
-						     NULL);
-		
-		if (file_move (window->archive_filename, dest_filename))
-			window_archive_close (window);
-	}
-	g_free (trash_path);
-}
-
-
 void
 activate_action_test_archive (GtkAction *action,
 			      gpointer   data)
@@ -1515,7 +1157,7 @@ activate_action_about (GtkAction *action,
 		"Breda McColgan",
 		NULL
 	};
-	const char       *translator_credits = _("translator_credits");
+	const char       *translator_credits = _("translator-credits");
 
 
 	if (about != NULL) {
@@ -1531,7 +1173,7 @@ activate_action_about (GtkAction *action,
 		      "comments", _("An archive manager for GNOME."),
 		      "authors", authors,
 		      "documenters", documenters,
-		      "translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		      "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 		      "logo_icon_name", "file-roller",
 		      "website", NULL,
 		      "website_label", NULL,
